@@ -136,9 +136,12 @@ def prepareDataset(init):
 	'''
 	This function needs to prepare the dataset for writing to HDF5
 	Need to sort by the event id information first
+	Then calculate the fletcher32 checksums for each value
 	Then do the bitshift operation on the waveform data
 	'''
-	indices = np.argsort(init['header']['eventid'])
+	#first do the sorting of the dataset
+	indices = np.argsort(init['header']['eventid']) 
+	dtype = init['header'][indices].dtype
 	headers = np.copy(init['header'][indices])
 	waveforms = np.copy(bf.doAnd(init['wave'][indices]))
 	del init
